==> haskell-lens-aeson-1.2.3-193.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-FAgRYVuU5157AZ98ZS6OOm
key:                  lens-aeson-1.2.3-FAgRYVuU5157AZ98ZS6OOm
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  2a98a5aae1414297ac2e9219f7816129
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-FAgRYVuU5157AZ98ZS6OOm
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2
    text-short-0.1.6-LT3hLgE3AIH5LX66Bu59Xl
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.2.3-194-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-4ImEZjcSS5v7sGC7rUGMR2
key:                  lens-aeson-1.2.3-4ImEZjcSS5v7sGC7rUGMR2
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  9c771647fd752b3722bd8497a6f2abf7
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-4ImEZjcSS5v7sGC7rUGMR2
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2
    text-short-0.1.6-uDJBdqgRh39kcxwO1KbRc
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
